# Strukturní metody rozpoznávání

Strukturní popisy rozpoznávaných objektů
- primitiva
- vlastnosti primitiv
- relace mezi primitivy
	- prostorové
	- časové
	- funkční

Vytvořený symbolický popis - obraz vystihuje (popisuje) strukturní vlastnosti objektu.

Strukturní popisy (obrazy)
- řetězec symbolů označující primitiva
- relační struktura
- graf (obecný, speciální, ...)

Strukturní popisy objektů (= slova) příslušejících do téže třídy tvoří jazyk třídy.

Rozpoznávání strukturně popsaných objektů = **rozhodnutí**, zda vytvořený strukturní popis objektu (slovo) **je slovem** (frází) **jazyka příslušné třídy**.

Výhody strukturních metod rozpoznávání:
- invariantní na pozici a natočení obrazu
- méně složité popisy u složitých objektů

**Tvorba strukturních popisů**
1. nalézt všechna primitiva a přiřadit jim prvky nosiče struktury
2. každému prvku struktury přiřadit vlastnost (unární relaci) označenou jménem (symbolem) odpovídajícího primitiva
3. určit vztahy mezi primitivy (binární relace), čímž vytvoříme relační strukturu
4. doplnit případnou informaci číselné povahy (vytvoříme sémantickou informaci, popř. sémantický vektor)

**Extrakce primitiv, vytváření strukturních obrazů**
1. počet typů (druhů) primitiv i relací (vztahů) mezi nimi by měl být co nejmenší
2. primitiva by měla odpovídat základním (přirozeným) strukturním elementům objektu, jimiž lze objekt vyčerpávajícím způsobem popsat; přitom primitiva musejí být snadno extrahovatelná a klasifikovatelná (nejčastěji některou příznakovou metodou)
3. nalezení (určení) primitiv a relací mezi nimi (způsob nalezení, algoritmus, …) by mělo být algoritmicky co nejjednodušší

**Příklady**
- extrakce primitiv Freemanovým kódem (směrová růžice)
- rozpoznávání geometrických objektů

# Příznakové metody rozpoznávání

Obrazy objektů jsou reprezentovány vektory příznaků $x$, **zařazování obrazů do tříd** se nazývá **klasifikace** deterministickým nebo stochastickým rozhodovacím pravidlem ve tvaru $\omega = d(x)$, resp. $\omega = d(x, q)$, kde
- $x$ je klasifikovaný obraz objektu,
- $q$ je vektor nastavení klasifikátoru.

**Dělení**
- klasické statistické metody rozpoznávání založené na použití tzv. diskriminačních funkcí (Fisher) nebo pravděpodobnostech příslušnosti ke klasifikačním třídám (Bayes)
+ metody založené na strojovém učení (učení z příkladů)
	+ učení s učitelem (supervised learning)
	+ učení bez učitele (unsupervized learning)
+ metody založené na použití umělých neuronových sítí, tzv. neuronové klasifikátory

**Klasifikátor s diskriminační funkcí**
- pro každou třídu určíme diskriminační funkci
- pro všechny obrazy patřící do $r$-té třídy musí platit
	- $g_{r}(x) > g_{s}(x), r\neq s$
- rozhodovací pravidlo
	- $\omega_{r} = \max(g_{s}(x))$

**Klasifikátor na principu kritéria minimální vzdálenosti**
- porovnávání klasifikovaných obrazů se vzorovými obrazy - tzv. etalony
- neznámé obrazy klasifikujeme stejně jako nejbližší klasifikované

**Kritérium minimální chyby** (Bayesův klasifikátor)
- pro úlohy s neoddělitelnými (prolínajícími se) třídami obrazů
- příslušnost k dané třídě lze určit jen s určitou pravděpodobností
